==> igniteui-webcomponents-layouts-4.3.2.tgz: package/esm5/lib/igc-tool-action-group-header-component.js <==
import { __extends } from "tslib";
import { IgcToolActionComponent } from "./igc-tool-action-component";
import { ToolActionGroupHeader } from "./ToolActionGroupHeader";
import { getAllPropertyNames, toSpinal, brushToString, stringToBrush } from "igniteui-webcomponents-core";
import { RegisterElementHelper } from "igniteui-webcomponents-core";
var IgcToolActionGroupHeaderComponent = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(IgcToolActionGroupHeaderComponent, _super);
    function IgcToolActionGroupHeaderComponent() {
        return _super.call(this) || this;
    }
    IgcToolActionGroupHeaderComponent.prototype.createImplementation = function () {
        return new ToolActionGroupHeader();
    };
    Object.defineProperty(IgcToolActionGroupHeaderComponent.prototype, "i", {
        /**
                                     * @hidden
                                     */
        get: function () {
            return this._implementation;
        },
        enumerable: false,
        configurable: true
    });
    IgcToolActionGroupHeaderComponent.prototype.connectedCallback = function () {
        if (_super.prototype["connectedCallback"]) {
            _super.prototype["connectedCallback"].call(this);
        }
        if (this.i.connectedCallback) {
            this.i.connectedCallback();
        }
        if (!this._attached) {
            this._attached = true;
            this._flushQueuedAttributes();
        }
    };
    IgcToolActionGroupHeaderComponent.prototype.disconnectedCallback = function () {
        if (_super.prototype["disconnectedCallback"]) {
            _super.prototype["disconnectedCallback"].call(this);
        }
        if (this.i.disconnectedCallback) {
            this.i.disconnectedCallback();
        }
        if (this._attached) {
            this._attached = false;
        }
    };
    Object.defineProperty(IgcToolActionGroupHeaderComponent, "observedAttributes", {
        get: function () {
            if (IgcToolActionGroupHeaderComponent._observedAttributesIgcToolActionGroupHeaderComponent == null) {
                var names = getAllPropertyNames(IgcToolActionGroupHeaderComponent);
                for (var i = 0; i < names.length; i++) {
                    names[i] = toSpinal(names[i]);
                }
                IgcToolActionGroupHeaderComponent._observedAttributesIgcToolActionGroupHeaderComponent = names;
            }
            return IgcToolActionGroupHeaderComponent._observedAttributesIgcToolActionGroupHeaderComponent;
        },
        enumerable: false,
        configurable: true
    });
    IgcToolActionGroupHeaderComponent.register = function () {
        if (!IgcToolActionGroupHeaderComponent._isElementRegistered) {
            IgcToolActionGroupHeaderComponent._isElementRegistered = true;
            RegisterElementHelper.registerElement(IgcToolActionGroupHeaderComponent.htmlTagName, IgcToolActionGroupHeaderComponent);
        }
    };
    Object.defineProperty(IgcToolActionGroupHeaderComponent.prototype, "actualBackIconColor", {
        /**
         * Gets the actual back icon color.
        */
        get: function () {
            return brushToString(this.i.fb);
        },
        set: function (v) {
            this.i.fb = stringToBrush(v);
            this._a("actualBackIconColor", brushToString(this.i.fb));
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgcToolActionGroupHeaderComponent.prototype, "backIconColor", {
        /**
         * Gets or sets the icon color for the back button.
        */
        get: function () {
            return brushToString(this.i.fc);
        },
        set: function (v) {
            this.i.fc = stringToBrush(v);
            this._a("backIconColor", brushToString(this.i.fc));
        },
        enumerable: false,
        configurable: true
    });
    IgcToolActionGroupHeaderComponent._observedAttributesIgcToolActionGroupHeaderComponent = null;
    IgcToolActionGroupHeaderComponent.htmlTagName = "igc-tool-action-group-header";
    IgcToolActionGroupHeaderComponent._isElementRegistered = false;
    return IgcToolActionGroupHeaderComponent;
}(IgcToolActionComponent));
export { IgcToolActionGroupHeaderComponent };

==> igniteui-webcomponents-layouts-4.8.0.tgz: package/esm5/lib/igc-tool-action-group-header-component.js <==
import { __extends } from "tslib";
import { IgcToolActionComponent } from "./igc-tool-action-component";
import { ToolActionGroupHeader } from "./ToolActionGroupHeader";
import { getAllPropertyNames, toSpinal, brushToString, stringToBrush } from "igniteui-webcomponents-core";
import { RegisterElementHelper } from "igniteui-webcomponents-core";
var IgcToolActionGroupHeaderComponent = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(IgcToolActionGroupHeaderComponent, _super);
    function IgcToolActionGroupHeaderComponent() {
        return _super.call(this) || this;
    }
    IgcToolActionGroupHeaderComponent.prototype.createImplementation = function () {
        return new ToolActionGroupHeader();
    };
    Object.defineProperty(IgcToolActionGroupHeaderComponent.prototype, "i", {
        /**
                                     * @hidden
                                     */
        get: function () {
            return this._implementation;
        },
        enumerable: false,
        configurable: true
    });
    IgcToolActionGroupHeaderComponent.prototype.connectedCallback = function () {
        if (_super.prototype["connectedCallback"]) {
            _super.prototype["connectedCallback"].call(this);
        }
        if (this.i.connectedCallback) {
            this.i.connectedCallback();
        }
        if (!this._attached) {
            this._attached = true;
            this._flushQueuedAttributes();
        }
    };
    IgcToolActionGroupHeaderComponent.prototype.disconnectedCallback = function () {
        if (_super.prototype["disconnectedCallback"]) {
            _super.prototype["disconnectedCallback"].call(this);
        }
        if (this.i.disconnectedCallback) {
            this.i.disconnectedCallback();
        }
        if (this._attached) {
            this._attached = false;
        }
    };
    Object.defineProperty(IgcToolActionGroupHeaderComponent, "observedAttributes", {
        get: function () {
            if (IgcToolActionGroupHeaderComponent._observedAttributesIgcToolActionGroupHeaderComponent == null) {
                var names = getAllPropertyNames(IgcToolActionGroupHeaderComponent);
                for (var i = 0; i < names.length; i++) {
                    names[i] = toSpinal(names[i]);
                }
                IgcToolActionGroupHeaderComponent._observedAttributesIgcToolActionGroupHeaderComponent = names;
            }
            return IgcToolActionGroupHeaderComponent._observedAttributesIgcToolActionGroupHeaderComponent;
        },
        enumerable: false,
        configurable: true
    });
    IgcToolActionGroupHeaderComponent.register = function () {
        if (!IgcToolActionGroupHeaderComponent._isElementRegistered) {
            IgcToolActionGroupHeaderComponent._isElementRegistered = true;
            RegisterElementHelper.registerElement(IgcToolActionGroupHeaderComponent.htmlTagName, IgcToolActionGroupHeaderComponent);
        }
    };
    Object.defineProperty(IgcToolActionGroupHeaderComponent.prototype, "actualBackIconColor", {
        /**
         * Gets the actual back icon color.
        */
        get: function () {
            return brushToString(this.i.ff);
        },
        set: function (v) {
            this.i.ff = stringToBrush(v);
            this._a("actualBackIconColor", brushToString(this.i.ff));
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgcToolActionGroupHeaderComponent.prototype, "backIconColor", {
        /**
         * Gets or sets the icon color for the back button.
        */
        get: function () {
            return brushToString(this.i.fg);
        },
        set: function (v) {
            this.i.fg = stringToBrush(v);
            this._a("backIconColor", brushToString(this.i.fg));
        },
        enumerable: false,
        configurable: true
    });
    IgcToolActionGroupHeaderComponent._observedAttributesIgcToolActionGroupHeaderComponent = null;
    IgcToolActionGroupHeaderComponent.htmlTagName = "igc-tool-action-group-header";
    IgcToolActionGroupHeaderComponent._isElementRegistered = false;
    return IgcToolActionGroupHeaderComponent;
}(IgcToolActionComponent));
export { IgcToolActionGroupHeaderComponent };
